function res= inputpol(varargin)
//-----------------------------------------------------------------------  
// function res= inputpol(varargin)
//  
// It is a function for Generating a polygon interactively. i.e
// indices are selcted by mouse clicks, or by draging the mouse
// in the newly generated graphics window.
//
// input:    varargin     variable No. of arguments list And the
//                        type of arguments can be: 
//  
//           'mode'       If it is present the next argument should
//                        be either 'click' or 'drag'(mode of drawing)
// 
//           'size'       If it is present the next argument should
//                        be a vector with the x,y co-ordinates of
//                        plotting region i.e. xmin,ymin,xmax,ymax.
//                        The default values are -5,-5,10,5
//                        respectively. 
//  
//           'noclose'    It should be present if we don't want to
//                        close the graphics window after drawing
//                        is finished(by default gr. window will be
//                        closed soon after drawing is finished).
//  
//           'no-nw'      It should be present If the user wants to
//                        draw in an already existing window.(i.e. no 
//                        new window, by default this routine
//                        chooses a new window for drawing).
//  
//           'marks'      it should be present if the user wants to 
//                        draw unconnected marks, it works only in
//                        default or 'click' mode
//
// output:   res          a matrix with indices of interactively
//                        generated polygon as its elements.
//  
//-----------------------------------------------------------------------  
//   $RCSfile: inputpol.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:15:07 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: inputpol.sci,v $
//  Revision 1.1  2003/10/16 12:15:07  haasdonk
//  intial version after release of presto-box 1.0, after renaming of old
//  repository patrec-lib
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
// setting the default values   
  Mode ='click'; 
  s =[-5,-5,10,5]; 
  clMode ='close'; 
  nw = 'nw'; 
  i = 1; 
  marks='lines';
  
  while i<= length(varargin),
    if varargin(i)== 'mode', 
      Mode = varargin(i+1); i=i+2;
    else
      if varargin(i)== 'marks',
	marks = varargin(i); i=i+1;
      else 
	if varargin(i)== 'size',
	  s = varargin(i+1);i=i+2;
	else
	  if varargin(i)== 'noclose',
	    clMode='noclose'; i=i+1;
	  else
	    if varargin(i)== 'no-nw',
	      nw='no-nw'; i=i+1;
	    else
	      error('error in the input argument!');
	    end
	  end
	end
      end
    end
  end
  
  
  if nw == 'nw',
    wi = new_window();
    xset("window", wi);
    xselect(); 
    xname('inputpol: '+Mode+'-mode');
  else 
    if nw== 'no-nw',
      xselect() 
      xbasc()
    end
  end
  
  // setting the region to perform interactive drawing
  plot2d([s(1),s(3),s(3),s(1)], [s(2),s(2),s(4),s(4)],0,"041",nax=[0, ...
		    round(s(3)-s(1)),0,round(s(4)-s(2))]);  
  
  // if drag Mode is selected
  if Mode =='drag',  
    
    xtitle(" First Click Left Mouse Button, Then Drag, And Then"+...
	   "Click Again To Terminate ")
    
    [b,x0,y0] = xclick(); 
    x = [x0;y0]; 
    y = [x0,y0,-1]; 
    
    while y(3) == -1,
      y = xgetmouse(0);
      if x(1,$) ~= y(1) | x(2,$) ~= y(2),
	x = [x,[y(1);y(2)]];
	xpoly([x(1,$-1),x(1,$)],[x(2,$-1),x(2,$)],"lines"); 
      end;
    end;
    xpoly([x(1,$),x0],[x(2,$),y0],"lines");
    res = x;
    if clMode == 'close', xdel(); 
    end;
    
    // default or if click mode is selected
  else
    
    xtitle(" Go on Clicking Left Mouse Botton, Then Click Right"+...
	   " mouse Botton To Terminate ")
    
    y= xclick(); x=[ y(2); y(3) ];
    
    if marks ~='marks',
      xset("mark",0,1);
    else
      xset('mark',2,0)
    end
    
    xpoly([y(2)],[y(3)],"marks");
    
    //while pressed mouse button is the left one       
    while y(1)==0,
      xc=xclick();
      
      if xc(1)~=0,
	y=xc;
      else
	if x(1,$)~=xc(2) | x(2,$)~=xc(3),
	  x=[x,[ xc(2); xc(3) ]];	  
	  if marks =='marks',
	    xpoly(xc(2), xc(3),"marks");
	  else
	    xpoly([y(2),xc(2)], [y(3),xc(3)],"lines");
	  end;
	  y= xc;	
	end;
      end
    end;
    
    if marks ~='marks',
      if x(1,1)~=x(1,$) | x(2,1)~=x(2,$) ,
	xpoly([x(1,$),x(1,1)], [x(2,$),x(2,1)],"lines"); 
      end;
    end;
    
    res = x;
    
    if clMode == 'close', 
      xdel(); 
    end
    
  end
  
endfunction



















