
function res =  simtrans(p, r, a, tv)

//-----------------------------------------------------------------------  
// function res =  simtrans(p, r, a, tv)
//
//  function "simtrans" is a routine performing simple similarity- 
//  transformation of a polygon 
//
// input:    p            is a 2*n matrix with indices of polygon 
//           r            scale-factor( r >= 0)
//           a            angle of rotation
//           tv           2*1 translation vector
//  
// output:   res          a  2 * n matrix with indices of the
//                        translated polygon as its elements  
//
//-----------------------------------------------------------------------  
//   $RCSfile: simtrans.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:15:07 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: simtrans.sci,v $
//  Revision 1.1  2003/10/16 12:15:07  haasdonk
//  intial version after release of presto-box 1.0, after renaming of old
//  repository patrec-lib
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
  [out, in] = argn(0);
  if in ~=4,
    error('wrong number of input arguments.');
  end;
  
  //   finding the no. of indices
  n = size(p,2); 
  v = 0;
  
  // duplicating translation vetor(tv) for n times and
  // then adding it to all the indices of the polygon
  if size(tv)== [2,1], 
    v(1, 1:n) = tv(1); 
    v(2, 1:n) = tv(2);
    res = r *[cos(a),-sin(a); sin(a),cos(a)] *p +v ;
  else 
    if size(tv)==[1,2], 
      v(1:n,1) = tv(1); 
      v(1:n,2) = tv(2);
      res = r *[cos(a), -sin(a); sin(a), cos(a)] *p +v' ;
    end 
  end

endfunction

