function [classes, cert] = nneigh_class(x, xlearn, labels)
//-----------------------------------------------------------------------  
// function [classes, cert] = nneigh_class(x, xlearn, labels)
//
// implementation of nearest neighbour classification 
// of two-dimensional vectors based on learning set. 
//
// input:    x            n1 times n2 - matrix consisting of n points to be 
//                        classified
//           xlearn       n1 times m - matrix consisting of learning 
//                        points
//           labels       m-vector of integer class-labels.             
//
// output:   classes      n2-vector of estimated class memberships, integers 
//           cert         n2-vector of "certainty" measures for the 
//                        classifications, in this case e^(-dmin^2)
//                        (only heuristic, no theoretic foundation for
//                        "certainty")
//
//-----------------------------------------------------------------------  
//   $RCSfile: nneigh_class.sci,v $
//  $Revision: 1.1 $
//      $Date: 2003/10/16 12:16:46 $
//  Copyright: IIF-LMB $Author: haasdonk $
//
//-----------------------------------------------------------------------
//  $Log: nneigh_class.sci,v $
//  Revision 1.1  2003/10/16 12:16:46  haasdonk
//  initial version after release of presto-box 1.0, after rename of old
//  repository patrec-lib
//
//  Revision 1.2  2002/11/21 17:53:48  poluru
//  removed usage of global variable: DATA and used
//  "get_function_path" to find path of the library.
//
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  [out,in] = argn(0);

  if in~=3,     
    if in~=1  
      error('wrong number of input arguments.');
    end; 
    
    //setting default classification data if it's not given by the
    //user. works only for 2-dimensional classification. 
    //"DATA" is the absolute path to the "data" directory. 
    //global DATA;
    //exec(DATA+'data.sci');
    
    path1 = get_function_path('nneigh_class');
    path2 = 'macros/classification/nneigh_class.sci';
    dir_path = part(path1, 1:length(path1)-length(path2) );
    exec(dir_path+'data/data.sci', -1);
    
    xlearn=V;
    labels=l;    
  end;
  
  n1 = size(x,1);
  n2 = size(x,2);
  m = size(xlearn,2);
  
  if n1~=size(xlearn,1),
    error('Dimensions of xlearn & data(x) should be equal');
  end;
  
  if m~=size(labels,2),
    if m~=size(labels,1),
      error('Length of xlearn & labels should be equal');
    end;
    labels=labels';
  end;
     
  // generate ntest x nlearn coordinate matrices by 'repetition' 
  testx  = list(); 
  learnx = list();
  distsqr= 0;
  
  for i=1:n1,
    testx(i) = x(i,:)' * ones(1,m);   
    learnx(i) = (xlearn(i,:)' * ones(1,n2))';   
    
    // generate squared-distance matrix for all learn/test-pairs
    distsqr = distsqr + (testx(i)-learnx(i)).^2 
  end
 
  
  // find minima and indices
  [distsqrmin, indmin] = min(distsqr,'c');
  classes = labels(indmin);
  cert = exp(-distsqrmin)';
  
endfunction










